[![codecov](https://codecov.io/github/ypochien/CoverBot/branch/main/graph/badge.svg?token=1SLWCSHXSY)](https://codecov.io/github/ypochien/CoverBot)
# CoverBot

## Brief

A monitor and execute stop loss trade package with Shioaji API
31 : IOC部份成交剩餘取消
51 : 價格穩定機制, 部份成交剩餘取消

A3 : 與控管基準價差距達 30% 以上
14 : 該筆委託已成交或委託單序號錯誤